@@ -6,9 +6,13 @@ SERVER = {
     'PASSWORD': 'b!gL4nd',
 }
 
-CHANNELS = [('#bottest',)]
+CHANNELS = [
+    ('#bottest',),
+]
 NICK = 'helgabot-dev'
 
+ENABLED_PLUGINS = ['stfu', 'help', 'oneliner', 'manager', 'updates']
+
 WEBHOOKS_CREDENTIALS = []
 
 NEWRELIC_WEBHOOK_ANNOUNCE_CHANNEL = '#bottest'
@@ -18,7 +22,7 @@ NEWRELIC_ACCOUNT_ID = '49454'
 FES_CONFLUENCE_USER = 'shaun.duncan'
 FES_CONFLUENCE_PASS = 'One19@3#2'
 #FES_CONFLUENCE_JSON_URL = 'http://intranet.cmgdigital.com/rest/prototype/1/content/21037618.json'
-FES_CONFLUENCE_JSON_URL = 'http://intranet.cmgdigital.com/rest/prototype/1/content/42611283.json'
+FES_CONFLUENCE_JSON_URL = 'http://intranet.cmgdigital.com/rest/prototype/1/content/21037618.json'
 FES_CONFLUENCE_EDIT_URL = 'http://intranet.cmgdigital.com/pages/editpage.action?pageId=42611283'
 
 JIRA_AUTH = ('sduncan', 'One19@3#2')
